@@ -2,7 +2,7 @@ import os
 import csv
 import json
 import pandas as pd
-from pybrary import constants
+from .. import constants
 
 
 def replace_file_extension(file_path, file_format='json'):
@@ -38,11 +38,19 @@ def dump_into_csv(data_list, output, index=False):
     df.to_csv(output, index=index, index_label='id', quoting=csv.QUOTE_ALL)
 
 
-def dump_into_json(data_list, output):
+def dump_into_json(data_list, output, indent=4):
     with open(output, 'w') as outFile:
-        json.dump(data_list, outFile)
+        json.dump(data_list, outFile, indent=indent)
 
 
 def read_csv(file_path):
     df = pd.read_csv(file_path)
     return df.to_dict('records')
+
+
+def get_category_from_category_id(category_id):
+    return constants.DATABRARY_VOLUME_CATEGORIES[category_id]
+
+
+def get_databrary_ext_from_format(format_id):
+    return constants.SUPPORTED_FORMATS[format_id]
